# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.contact import Contact  # noqa: E501
from frontoffice.rest import ApiException

class TestContact(unittest.TestCase):
    """Contact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Contact
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.contact.Contact()  # noqa: E501
        if include_optional :
            return Contact(
                uuid = '69d6d7c8-59de-48b8-a2a1-49ce4a06b58a', 
                version = 56, 
                identificatie = 'a', 
                administratie = '0', 
                relatiesoort = '0', 
                persoonsnummer = '0', 
                persoonsgegevens = null, 
                contactgegevens_events = [
                    frontoffice.models.contactgegevens_event.ContactgegevensEvent(
                        bron = '0', 
                        correlatie_id = '0', 
                        event_datum_bron = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_title = '0', 
                        indiener = '0', 
                        event_payload = null, 
                        aanmaakdatum = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_id = 'c8255641-04a6-4e0a-9d3b-bc19bc91aa74', )
                    ], 
                contactgegevens = null
            )
        else :
            return Contact(
                identificatie = 'a',
        )

    def testContact(self):
        """Test Contact"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import frontoffice
from frontoffice.api.developer_tools_api import DeveloperToolsApi  # noqa: E501
from frontoffice.rest import ApiException


class TestDeveloperToolsApi(unittest.TestCase):
    """DeveloperToolsApi unit test stubs"""

    def setUp(self):
        self.api = frontoffice.api.developer_tools_api.DeveloperToolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_contact_v2_dev_contact_get(self):
        """Test case for get_contact_v2_dev_contact_get

        Get Contact  # noqa: E501
        """
        pass

    def test_get_settings_v2_dev_settings_get(self):
        """Test case for get_settings_v2_dev_settings_get

        Get Settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.contactpersoon_gegevens import ContactpersoonGegevens  # noqa: E501
from frontoffice.rest import ApiException

class TestContactpersoonGegevens(unittest.TestCase):
    """ContactpersoonGegevens unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContactpersoonGegevens
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.contactpersoon_gegevens.ContactpersoonGegevens()  # noqa: E501
        if include_optional :
            return ContactpersoonGegevens(
                email = '0', 
                adressen = [
                    frontoffice.models.adres_mutatie.AdresMutatie(
                        soort = 'Domicilie', 
                        postcode = '0', 
                        straat = '0', 
                        land = '0', 
                        huisnummer = 56, 
                        huisnummertoevoeging = '0', 
                        landnaam = '0', 
                        verwijderd = True, 
                        einddatum = '0', )
                    ], 
                kanaalvoorkeur = 'POST', 
                nieuwsbrief = True, 
                klanttevredenheidsonderzoek = True, 
                magazine = 'POST', 
                telefoonnummer1 = 'a', 
                telefoonnummer2 = 'a', 
                email_adresseerbaar = True, 
                voornaam = '0', 
                achternaam = '0', 
                werkgevernummer = '0', 
                functie = '0', 
                actief = True, 
                aanhef = '0', 
                tussenvoegsel = '0'
            )
        else :
            return ContactpersoonGegevens(
        )

    def testContactpersoonGegevens(self):
        """Test ContactpersoonGegevens"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.settings import Settings  # noqa: E501
from frontoffice.rest import ApiException

class TestSettings(unittest.TestCase):
    """Settings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Settings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.settings.Settings()  # noqa: E501
        if include_optional :
            return Settings(
                env = 'fb', 
                runtime = 'basic'
            )
        else :
            return Settings(
        )

    def testSettings(self):
        """Test Settings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.persoons_gegevens import PersoonsGegevens  # noqa: E501
from frontoffice.rest import ApiException

class TestPersoonsGegevens(unittest.TestCase):
    """PersoonsGegevens unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PersoonsGegevens
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.persoons_gegevens.PersoonsGegevens()  # noqa: E501
        if include_optional :
            return PersoonsGegevens(
                burgerservicenummer = '0', 
                persoonsnummer = '0', 
                relatienummer = '0', 
                anummer = '0', 
                naam = '0', 
                voornamen = '0', 
                voorlettes = '0', 
                voorvoegsels = '0', 
                naamgebruik = '0', 
                opgemaakte_naam = '0', 
                voorkeursnaam = '0', 
                geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                    dag = 56, 
                    maand = 56, 
                    jaar = 56, ), 
                overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                    dag = 56, 
                    maand = 56, 
                    jaar = 56, ), 
                geslacht = '0', 
                partner_naam = '0', 
                partner_voorvoegsels = '0', 
                gba_status = '0', 
                afnemersindicatie = True, 
                partnerschappen = [
                    frontoffice.models.partnerschap.Partnerschap(
                        partner = frontoffice.models.persoons_gegevens_basic.PersoonsGegevensBasic(
                            burgerservicenummer = '0', 
                            persoonsnummer = '0', 
                            relatienummer = '0', 
                            anummer = '0', 
                            naam = '0', 
                            voornamen = '0', 
                            voorlettes = '0', 
                            voorvoegsels = '0', 
                            naamgebruik = '0', 
                            opgemaakte_naam = '0', 
                            voorkeursnaam = '0', 
                            geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                                dag = 56, 
                                maand = 56, 
                                jaar = 56, ), 
                            overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                                dag = 56, 
                                maand = 56, 
                                jaar = 56, ), 
                            geslacht = '0', 
                            partner_naam = '0', 
                            partner_voorvoegsels = '0', ), 
                        soort = '0', 
                        begindatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), 
                        einddatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), )
                    ], 
                kinderen = [
                    frontoffice.models.persoons_gegevens_basic.PersoonsGegevensBasic(
                        burgerservicenummer = '0', 
                        persoonsnummer = '0', 
                        relatienummer = '0', 
                        anummer = '0', 
                        naam = '0', 
                        voornamen = '0', 
                        voorlettes = '0', 
                        voorvoegsels = '0', 
                        naamgebruik = '0', 
                        opgemaakte_naam = '0', 
                        voorkeursnaam = '0', 
                        geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), 
                        overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), 
                        geslacht = '0', 
                        partner_naam = '0', 
                        partner_voorvoegsels = '0', )
                    ], 
                ouders = [
                    frontoffice.models.persoons_gegevens_basic.PersoonsGegevensBasic(
                        burgerservicenummer = '0', 
                        persoonsnummer = '0', 
                        relatienummer = '0', 
                        anummer = '0', 
                        naam = '0', 
                        voornamen = '0', 
                        voorlettes = '0', 
                        voorvoegsels = '0', 
                        naamgebruik = '0', 
                        opgemaakte_naam = '0', 
                        voorkeursnaam = '0', 
                        geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), 
                        overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                            dag = 56, 
                            maand = 56, 
                            jaar = 56, ), 
                        geslacht = '0', 
                        partner_naam = '0', 
                        partner_voorvoegsels = '0', )
                    ]
            )
        else :
            return PersoonsGegevens(
                persoonsnummer = '0',
        )

    def testPersoonsGegevens(self):
        """Test PersoonsGegevens"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import frontoffice
from frontoffice.api.contactgegevens_api import ContactgegevensApi  # noqa: E501
from frontoffice.rest import ApiException


class TestContactgegevensApi(unittest.TestCase):
    """ContactgegevensApi unit test stubs"""

    def setUp(self):
        self.api = frontoffice.api.contactgegevens_api.ContactgegevensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get(self):
        """Test case for get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get

        Get Events  # noqa: E501
        """
        pass

    def test_get_search_core_v2_search_core_administratie_get(self):
        """Test case for get_search_core_v2_search_core_administratie_get

        Get Search Core  # noqa: E501
        """
        pass

    def test_get_search_pere_v2_search_pere_administratie_get(self):
        """Test case for get_search_pere_v2_search_pere_administratie_get

        Get Search Pere  # noqa: E501
        """
        pass

    def test_get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get(self):
        """Test case for get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get

        Get Snapshot  # noqa: E501
        """
        pass

    def test_put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post(self):
        """Test case for put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post

        Put Event  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.adres_mutatie import AdresMutatie  # noqa: E501
from frontoffice.rest import ApiException

class TestAdresMutatie(unittest.TestCase):
    """AdresMutatie unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdresMutatie
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.adres_mutatie.AdresMutatie()  # noqa: E501
        if include_optional :
            return AdresMutatie(
                soort = 'Domicilie', 
                postcode = '0', 
                straat = '0', 
                land = '0', 
                huisnummer = 56, 
                huisnummertoevoeging = '0', 
                landnaam = '0', 
                verwijderd = True, 
                einddatum = '0'
            )
        else :
            return AdresMutatie(
                soort = 'Domicilie',
        )

    def testAdresMutatie(self):
        """Test AdresMutatie"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.partnerschap import Partnerschap  # noqa: E501
from frontoffice.rest import ApiException

class TestPartnerschap(unittest.TestCase):
    """Partnerschap unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Partnerschap
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.partnerschap.Partnerschap()  # noqa: E501
        if include_optional :
            return Partnerschap(
                partner = frontoffice.models.persoons_gegevens_basic.PersoonsGegevensBasic(
                    burgerservicenummer = '0', 
                    persoonsnummer = '0', 
                    relatienummer = '0', 
                    anummer = '0', 
                    naam = '0', 
                    voornamen = '0', 
                    voorlettes = '0', 
                    voorvoegsels = '0', 
                    naamgebruik = '0', 
                    opgemaakte_naam = '0', 
                    voorkeursnaam = '0', 
                    geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                        dag = 56, 
                        maand = 56, 
                        jaar = 56, ), 
                    overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                        dag = 56, 
                        maand = 56, 
                        jaar = 56, ), 
                    geslacht = '0', 
                    partner_naam = '0', 
                    partner_voorvoegsels = '0', ), 
                soort = '0', 
                begindatum = frontoffice.models.datum_delen.DatumDelen(
                    dag = 56, 
                    maand = 56, 
                    jaar = 56, ), 
                einddatum = frontoffice.models.datum_delen.DatumDelen(
                    dag = 56, 
                    maand = 56, 
                    jaar = 56, )
            )
        else :
            return Partnerschap(
                partner = frontoffice.models.persoons_gegevens_basic.PersoonsGegevensBasic(
                    burgerservicenummer = '0', 
                    persoonsnummer = '0', 
                    relatienummer = '0', 
                    anummer = '0', 
                    naam = '0', 
                    voornamen = '0', 
                    voorlettes = '0', 
                    voorvoegsels = '0', 
                    naamgebruik = '0', 
                    opgemaakte_naam = '0', 
                    voorkeursnaam = '0', 
                    geboortedatum = frontoffice.models.datum_delen.DatumDelen(
                        dag = 56, 
                        maand = 56, 
                        jaar = 56, ), 
                    overlijdensdatum = frontoffice.models.datum_delen.DatumDelen(
                        dag = 56, 
                        maand = 56, 
                        jaar = 56, ), 
                    geslacht = '0', 
                    partner_naam = '0', 
                    partner_voorvoegsels = '0', ),
                soort = '0',
                begindatum = frontoffice.models.datum_delen.DatumDelen(
                    dag = 56, 
                    maand = 56, 
                    jaar = 56, ),
        )

    def testPartnerschap(self):
        """Test Partnerschap"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
